==> open-xchange-admin_7.2.2.orig.tar.bz2: open-xchange-admin-7.2.2/com.openexchange.admin.console/src/com/openexchange/admin/console/publication/DeleteCore.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.admin.console.publication;

import java.rmi.RemoteException;
import com.openexchange.admin.console.AdminParser;
import com.openexchange.admin.rmi.OXPublicationInterface;
import com.openexchange.admin.rmi.dataobjects.Credentials;
import com.openexchange.admin.rmi.dataobjects.Publication;
import com.openexchange.admin.rmi.exceptions.DuplicateExtensionException;

public abstract class DeleteCore extends PublicationAbstraction {

    protected final void commonfunctions(final AdminParser parser, final String[] args) {
        setOptions(parser);

        String successtext = null;
        try {
            parser.ownparse(args);

            final Credentials auth = credentialsparsing(parser);

            final OXPublicationInterface oxpub = getPublicationInterface();

            final Publication publication = new Publication();

            maincall(parser, oxpub, publication, auth);

            boolean success = oxpub.deletePublication(publication.getContext(), publication.getUrl(), auth);
            if (success) {
                successtext = "Publication successfully deleted";
            } else {
                successtext = "Failed deleting publication";
            }
            
            displayDeletedMessage(successtext, null, parser);
            sysexit(0);
        } catch (final Exception e) {
            printErrors(successtext, null, e, parser);
        }
    }

    protected abstract void maincall(final AdminParser parser, final OXPublicationInterface oxpub, final Publication pub, final Credentials auth) throws RemoteException, DuplicateExtensionException;
}

==> open-xchange-admin_7.4.0.orig.tar.bz2: open-xchange-admin-7.4.0/com.openexchange.admin.console/src/com/openexchange/admin/console/publication/DeleteCore.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.admin.console.publication;

import java.rmi.RemoteException;
import com.openexchange.admin.console.AdminParser;
import com.openexchange.admin.rmi.OXPublicationInterface;
import com.openexchange.admin.rmi.dataobjects.Credentials;
import com.openexchange.admin.rmi.dataobjects.Publication;
import com.openexchange.admin.rmi.exceptions.DuplicateExtensionException;

public abstract class DeleteCore extends PublicationAbstraction {

    protected final void commonfunctions(final AdminParser parser, final String[] args) {
        setOptions(parser);

        boolean error = true;
        String successtext = null;
        try {
            parser.ownparse(args);

            final Credentials auth = credentialsparsing(parser);

            final OXPublicationInterface oxpub = getPublicationInterface();

            final Publication publication = new Publication();

            maincall(parser, oxpub, publication, auth);

            boolean success = oxpub.deletePublication(publication.getContext(), publication.getUrl(), auth);
            if (success) {
                successtext = "Publication with URL \"" + publication.getUrl() + "\" successfully deleted from context " + publication.getContext().getId();
                error = false;
            } else {
                successtext = "Failed to delete publication with URL \"" + publication.getUrl() + "\" from context " + publication.getContext().getId();
                error = true;
            }
            System.out.println(successtext);
        } catch (final Exception e) {
            printErrors(successtext, null, e, parser);
        } finally {
            if (error) {
                sysexit(SYSEXIT_UNKNOWN_OPTION);
            }
        }
    }

    protected abstract void maincall(final AdminParser parser, final OXPublicationInterface oxpub, final Publication pub, final Credentials auth) throws RemoteException, DuplicateExtensionException;
}
